@@ -15,7 +15,7 @@ fn main() -> ! {
     // Initialize the allocator BEFORE you use it
     let start = cortex_m_rt::heap_start() as usize;
     let size = 1024; // in bytes
-    unsafe { umm_malloc::init(start, size) };
+    unsafe { umm_malloc::init_heap(start, size) };
 
     let mut xs = Vec::new();
     xs.push(1);
